<?php

/**
 * Patient Portal
 *
 * @package   OpenEMR
 * @link      http://www.open-emr.org
 * @author    Jerry Padgett <sjpadgett@gmail.com>
 * @author    Tyler Wrenn <tyler@tylerwrenn.com>
 * @copyright Copyright (c) 2016-2020 Jerry Padgett <sjpadgett@gmail.com>
 * @copyright Copyright (c) 2020 Tyler Wrenn <tyler@tylerwrenn.com>
 * @license   https://github.com/openemr/openemr/blob/master/LICENSE GNU General Public License 3
 */

use OpenEMR\Core\Header;

$pid = $this->cpid;
$recid = $this->recid;
$docid = $this->docid;
$is_module = $this->is_module;
$is_portal = $this->is_portal;
$is_dashboard = (empty($is_module) && empty($is_portal));
$category = $this->save_catid;
$new_filename = $this->new_filename;
$webroot = $GLOBALS['web_root'];
$encounter = '';
$include_auth = true;
// for location assign
$referer = $GLOBALS['web_root'] . "/controller.php?document&upload&patient_id=" . attr_url($pid) . "&parent_id=" . attr_url($category) . "&";

if (empty($is_module)) {
    $this->assign('title', xlt("Patient Portal") . " | " . xlt("Documents"));
} else {
    $this->assign('title', xlt("Document Templates"));
}
$this->assign('nav', 'onsitedocuments');

$catname = '';
if ($category) {
    $result = sqlQuery("SELECT name FROM categories WHERE id = ?", array($category));
    $catname = $result['name'] ?: '';
}
$catname = $catname ?: xlt("Onsite Portal Reviewed");

if (!$docid) {
    $docid = 'Privacy_Document';
}

$isnew = false;
$ptName = $_SESSION['ptName'] ?? $pid;
$cuser = $_SESSION['sessionUser'] ?? $_SESSION['authUserID'];
?>
<!DOCTYPE html>
<html>
<head>
    <title><?php
    if ($is_dashboard) {
        echo xlt("Portal Document Review");
    } elseif (empty($is_module)) {
        echo xlt("Patient Portal Documents");
    } else {
        echo xlt("Patient Document Templates");
    }
    ?>
    </title>
    <meta name="description" content="Developed By sjpadgett@gmail.com">
    <?php
// some necessary js globals
    echo "<script>var cpid=" . js_escape($pid) . ";var cuser=" . js_escape($cuser) . ";var ptName=" . js_escape($ptName) .
    ";var catid=" . js_escape($category) . ";var catname=" . js_escape($catname) . ";</script>";
    echo "<script>var recid=" . js_escape($recid) . ";var docid=" . js_escape($docid) . ";var isNewDoc=" . js_escape($isnew) . ";var newFilename=" . js_escape($new_filename) . ";</script>";
    echo "<script>var isPortal=" . js_escape($is_portal) . ";var isModule=" . js_escape($is_module) . ";var webRoot=" . js_escape($webroot) . ";var webroot_url = webRoot;</script>";
// translations
    echo "<script>var alertMsg1='" . xlt("Saved to Patient Documents") . '->' . xlt("Category") . ": " . attr($catname) . "';</script>";
    echo "<script>var msgSuccess='" . xlt("Updates Successful") . "';</script>";
    echo "<script>var msgDelete='" . xlt("Delete Successful") . "';</script>";

    Header::setupHeader(['no_main-theme', 'patientportal-style', 'datetime-picker']);

    ?>
    <link href="<?php echo $GLOBALS['web_root']; ?>/portal/sign/css/signer_modal.css?v=<?php echo $GLOBALS['v_js_includes']; ?>" rel="stylesheet">
    <script src="<?php echo $GLOBALS['web_root']; ?>/portal/sign/assets/signature_pad.umd.js?v=<?php echo $GLOBALS['v_js_includes']; ?>"></script>
    <script src="<?php echo $GLOBALS['web_root']; ?>/portal/sign/assets/signer_api.js?v=<?php echo $GLOBALS['v_js_includes']; ?>"></script>
    <script src="<?php echo $GLOBALS['web_root']; ?>/portal/patient/scripts/libs/LAB.min.js"></script>
    <script>
        $LAB.setGlobalDefaults({
            BasePath: "<?php $this->eprint($this->ROOT_URL); ?>"
        });
        $LAB.script("<?php echo $GLOBALS['assets_static_relative']; ?>/underscore/underscore-min.js").script("<?php echo $GLOBALS['assets_static_relative']; ?>/moment/moment.js").script(
            "<?php echo $GLOBALS['assets_static_relative']; ?>/backbone/backbone-min.js").script("<?php echo $GLOBALS['web_root']; ?>/portal/patient/scripts/app.js?v=<?php echo $GLOBALS['v_js_includes']; ?>").script(
            "<?php echo $GLOBALS['web_root']; ?>/portal/patient/scripts/model.js?v=<?php echo $GLOBALS['v_js_includes']; ?>").wait().script(
            "<?php echo $GLOBALS['web_root']; ?>/portal/patient/scripts/view.js?v=<?php echo $GLOBALS['v_js_includes']; ?>").wait()
    </script>
    <style>
        @media print {
            #templatecontent {
                width: 1220px;
            }
        }

        .nav-pills-ovr>li>a {
            border: 1px solid !important;
            border-radius: .25rem !important;
        }
    </style>
</head>

<body class="p-0 m-0">
    <script>
        <?php require($GLOBALS['srcdir'] . '/js/xl/jquery-datetimepicker-2-5-4-alternate.js.php'); ?>
        $LAB.script("<?php echo $GLOBALS['web_root']; ?>/portal/patient/scripts/app/onsitedocuments.js?v=<?php echo $GLOBALS['v_js_includes']; ?>").wait().script(
            "<?php echo $GLOBALS['web_root']; ?>/portal/patient/scripts/app/onsiteportalactivities.js?v=<?php echo $GLOBALS['v_js_includes']; ?>").
        wait(function() {
            page.init();
            pageAudit.init();
            if (isPortal) {
                $('#Help').on('click', function (e) {
                    e.preventDefault();
                    $(".helpHide").addClass("d-none");
                });
                $("#Help").click();
                $(".helpHide").addClass("d-none");
            }
            console.log('init done template');

            setTimeout(function () {
                if (!page.isInitialized) {
                    page.init();
                    if (!pageAudit.isInitialized) {
                        pageAudit.init();
                    }
                }
            }, 2000);
        });

        function printaDoc(divName) {
            flattenDocument();
            divName = 'templatediv';
            let printContents = document.getElementById(divName).innerHTML;
            let originalContents = document.body.innerHTML;
            document.body.innerHTML = printContents;
            window.print();
            document.body.innerHTML = originalContents;
            location.reload();
        }

        function templateText(el) {
            $(el).data('textvalue', $(el).val());
        $(el).attr("data-textvalue", $(el).val())
            return false;
        }

        function templateCheckMark(el) {
            if ($(el).data('value') === 'Yes') {
                $(el).data('value', 'No');
                $(el).attr('data-value', 'No');
            } else {
                $(el).data('value', 'Yes');
                $(el).attr('data-value', 'Yes');
            }
            return false;
        }

        function templateRadio(el) {
            var rid = $(el).data('id')
            $('#rgrp' + rid).data('value', $(el).val());
            $('#rgrp' + rid).attr('data-value', $(el).val());
        $(el).prop('checked', true)
        return false;
    }

    function tfTemplateRadio(el) {
        var rid = $(el).data('id')
        $('#tfrgrp' + rid).data('value', $(el).val());
        $('#tfrgrp' + rid).attr('data-value', $(el).val());
            $(el).prop('checked', true);
            return false;
        }

        function replaceTextInputs() {
            $('.templateInput').each(function() {
                var rv = $(this).data('textvalue');
                $(this).replaceWith(rv);
            });
        }

        function replaceRadioValues() {
            $('.ynuGroup').each(function() {
            var gid = $(this).data('id');
            var grpid = $(this).prop('id');
            var rv = $('input:radio[name="ynradio' + gid + '"]:checked').val();
            $(this).replaceWith(rv);
        });

        $('.tfuGroup').each(function () {
            var gid = $(this).data('id');
            var grpid = $(this).prop('id');
            var rv = $('input:radio[name="tfradio' + gid + '"]:checked').val();
                $(this).replaceWith(rv);
            });
        }

        function replaceCheckMarks() {
            $('.checkMark').each(function() {
                var ckid = $(this).data('id');
                var v = $('#' + ckid).data('value');
            if (v === 'Yes')
                $(this).replaceWith('[\u2713]')
            else {
                $(this).replaceWith("[ ]")
                }
            });
        }

        function restoreTextInputs() {
            $('.templateInput').each(function() {
                var rv = $(this).data('textvalue');
            $(this).val(rv)
            });
        }

        function restoreRadioValues() {
            $('.ynuGroup').each(function() {
                var gid = $(this).data('id');
                var grpid = $(this).prop('id');
                var value = $(this).data('value');
                $("input[name=ynradio" + gid + "][value='" + value + "']").prop('checked', true);
            });

        $('.tfuGroup').each(function () {
            var gid = $(this).data('id');
            var grpid = $(this).prop('id');
            var value = $(this).data('value');
            $("input[name=tfradio" + gid + "][value='" + value + "']").prop('checked', true);
        });
        }

        function restoreCheckMarks() {
            $('.checkMark').each(function() {
                var ckid = $(this).data('id');
            if ($('#' + ckid).data('value') === 'Yes')
                    $('#' + ckid).prop('checked', true);
            else
                    $('#' + ckid).prop('checked', false);
            });
        }

        function replaceSignatures() {
            $('.signature').each(function() {
                let type = $(this).data('type');
                if ($(this).attr('src') !== signhere && $(this).attr('src')) {
                    $(this).removeAttr('data-action');
                }
                if (!isPortal) {
                    $(this).attr('data-user', cuser);
                }
            });
        }

        function flattenDocument() {
            replaceCheckMarks();
            replaceRadioValues();
            replaceTextInputs();
            replaceSignatures();
        }

        function restoreDocumentEdits() {
            restoreCheckMarks();
            restoreRadioValues();
            restoreTextInputs();
        }
    </script>
    <div class="container-fluid">
    <nav id="verytop" class="nav navbar-light bg-light navbar-expand p-1 m-1 sticky-top">
        <a class="navbar-brand ml-auto"><h3><?php echo xlt("Document Center") ?></h3></a>
        <div id="topmenu" class="mr-auto">
            <ul class="navbar-nav mr-auto">
                <li class="nav-item mb-1">
                    <a class="nav-link text-success btn btn-outline-success" onclick="$('.historyHide').toggleClass('d-none');document.getElementById('historyTable').scrollIntoView({behavior: 'smooth'})"><i class="fa fa-toggle-on mr-1" aria-hidden="true"></i><?php echo xlt("Show/Hide History") ?>
                    </a>
                </li>
                <?php if (empty($is_module)) { ?>
                    <li class="nav-item mb-1">
                        <a id="Help" class="nav-link text-primary btn btn-outline-primary" onclick='page.newDocument(cpid, cuser, "Help.tpl");'><?php echo xlt('Help'); ?></a>
                    </li>
                    <li class="nav-item nav-item mb-1">
                        <a class="nav-link btn btn-secondary" data-toggle="tooltip" title="Refresh" id="refreshPage" href="javascript:" onclick="window.location.reload()"> <span class="fa fa-sync fa-lg"></span>
                        </a>
                    </li>
                    <!-- future popout-->
                    <!--<li class="nav-item mb-1">
                        <a class="nav-link text-danger btn btn-outline-danger" onclick='window.location.replace("./../home.php")'><?php /*echo xlt('Home'); */?></a>
                    </li>-->
                <?php } else { ?>
                    <li class="nav-item mb-1">
                        <a class="nav-link text-danger btn btn-secondary" id="a_docReturn" href="#" onclick='window.location.replace("<?php echo $referer ?>")'><?php echo xlt('Return'); ?></a>
                    </li>
                <?php } ?>
            </ul>
        </div>
    </nav>
    <div class="d-flex flex-row justify-content-start">
        <!-- Pending documents menu left -->
        <div class="align-self-start sticky-top" id="topnav">
            <ul class="nav flex-column nav-pills nav-pills-ovr">
                <div class="navbar-header mt-3">
                    <a class="navbar-brand mx-1 mb-2 text-primary" href="#"><h4><i class="fa fa-edit mr-2 ml-0"></i><?php echo xla('Pending') ?></h4></a>
                </div>
                <?php require_once __DIR__ . '/../../lib/template_menu.php'; ?>
                <?php if (empty($is_module)) { ?>
                    <!-- will use later for pop out -->
                    <!--<strong><hr class="mb-2 mt-1" /></strong>
                    <li class="nav-item mb-1">
                        <a class="nav-link text-danger btn btn-outline-danger" onclick='window.location.replace("./../home.php")'><?php /*echo xlt('Home'); */?></a>
                    </li>-->
                <?php } else { ?>
                    <li class="nav-item mb-1">
                        <a class="nav-link text-danger btn btn-secondary" id="a_docReturn" href="#" onclick='window.location.replace("<?php echo $referer ?>")'><?php echo xlt('Return'); ?></a>
                    </li>
                <?php } ?>
            </ul>
            <div id="collectionAlert"></div>
        </div><!-- close left pending -->
        <!-- Right editor container -->
        <div class="flex-column col-md-9 col-lg-10">
<!-- document editor and action toolbar template -->
<script type="text/template" id="onsiteDocumentModelTemplate">
        <div class="card p-2 m-1" id="docpanel">
            <nav class="nav navbar-light navbar-expand bg-light sticky-top helpHide">
                <!-- Sticky actions toolbar -->
                <div class="py-2 mr-auto ml-auto">
                    <div class="collapse navbar-collapse">
                        <a class="navbar-brand" href="#"><?php echo xlt('Form Actions') ?></a>
                        <ul class="navbar-nav">
                            <li class="nav-item"><a class="nav-link btn btn-outline-primary" id="signTemplate" href="#openSignModal" data-toggle="modal" data-backdrop="true" data-target="#openSignModal" data-type="patient-signature"><?php echo xlt('Signature'); ?></a></li>
                            <li class="nav-item"><a class="nav-link btn btn-outline-primary" id="saveTemplate" href="#"><?php echo xlt('Save'); ?></a></li>
                            <li class="nav-item"><a class="nav-link btn btn-outline-primary" id="printTemplate" href="javascript:;" onclick="printaDoc('templatecontent');"><?php echo xlt('Print'); ?></a></li>
                            <li class="nav-item"><a class="nav-link btn btn-outline-primary" id="submitTemplate" href="#"><?php echo xlt('Download'); ?></a></li>
                            <li class="nav-item"><a class="nav-link btn btn-outline-primary" id="sendTemplate" href="#"><?php echo xlt('Send for Review'); ?></a></li>
                            <li class="nav-item"><a class="nav-link btn btn-outline-primary" id="chartTemplate" href="#"><?php echo xlt('Chart to Category') . ' ' . text($catname); ?></a></li>
                            <li class="nav-item"><a class="nav-link btn btn-outline-primary" id="downloadTemplate" href="#"><?php echo xlt('Download'); ?></a></li>
                            <li class="nav-item"><a class="nav-link btn btn-outline-primary" id="chartHistory" href="#"><?php echo xlt('Chart History'); ?></a></li>
                            <?php if (empty($is_module)) { ?>
                                <!-- future popout -->
                                <!--<li class="nav-item">
                                    <a class="nav-link text-danger" id="homeTemplate" href="#" onclick='history.go(0);'><?php /*echo xlt('Dismiss'); */?></a>
                                </li>-->
                            <?php } else { ?>
                                <li class="nav-item">
                                    <a class="nav-link text-danger" id="homeTemplate" href="#" onclick='window.location.replace("<?php echo $referer ?>")'><?php echo xlt('Return'); ?></a>
                                </li>
                            <?php } ?>
                        </ul>
                    </div>
                </div>
            </nav>
            <!-- Document edit container -->
            <header class="card-header bg-dark text-light helpHide" id='docPanelHeader'><?php echo xlt('Editing'); ?></header>
            <!-- editor form -->
            <form id='template' name='template' role="form" action="./../lib/doc_lib.php" method="POST">
                <div id="templatediv" class="card-body border p-2 m-1 bg-white h-100 overflow-auto">
                    <div id="templatecontent" class="template-body bg-white"><div class="text-center"><i class="fa fa-circle-notch fa-spin fa-3x ml-auto"></i></div></div>
                </div>
                <input type="hidden" name="content" id="content" value="" />
                <input type="hidden" name="cpid" id="cpid" value="" />
                <input type="hidden" name="docid" id="docid" value="" />
                <input type="hidden" name="handler" id="handler" value="download" />
                <input type="hidden" name="status" id="status" value="Open" />
            </form>
            <div class="clearfix">
            <span>
                <button id="dismissOnsiteDocumentButton" class="btn btn-sm btn-link float-right" onclick="history.go(0);"><?php echo xlt('Dismiss Form'); ?></button>
            </span>
            <!-- delete button is a separate form to prevent enter key from triggering a delete-->
            <form id="deleteOnsiteDocumentButtonContainer" class="form-inline" onsubmit="return false;">
                <fieldset>
                    <div class="form-group">
                        <label class="col-form-label"></label>
                        <div class="controls">
                            <button id="deleteOnsiteDocumentButton" class="btn btn-sm btn-danger"><i class="icon-trash icon-white"></i><?php echo xlt('Delete Document'); ?></button>
                            <span id="confirmDeleteOnsiteDocumentContainer">
                                <button id="cancelDeleteOnsiteDocumentButton" class="btn btn-link btn-sm"><?php echo xlt('Cancel'); ?></button>
                                <button id="confirmDeleteOnsiteDocumentButton" class="btn btn-sm btn-danger"><?php echo xlt('Confirm'); ?></button>
                          </span>
                        </div>
                    </div>
                </fieldset>
            </form>
        </div>
</script>
<div id="onsiteDocumentModelContainer" class="modelContainer">
    <!-- rendered edit document and action toolbar template -->
</div>
</div><!-- close flex right-->
</div><!-- close flex row -->

<!-- Now history table container template -->
<script type="text/template" id="onsiteDocumentCollectionTemplate">
        <div class="table-responsive pt-3">
            <h4 class="text-sm-center"><?php echo xlt('Your Document History') ?><small> (Click on label to sort.)</small></h4>
            <table class="collection table table-sm table-hover">
                <thead class='thead-dark'>
                <tr class='cursor-pointer'>
                    <th scope="col" id="header_Id"><?php echo xlt('Id'); ?><% if (page.orderBy == 'Id') { %> <i class='icon-arrow-<%= page.orderDesc ? ' up' : 'down' %>' /><% } %></th>
                    <th scope="col" id="header_DocType"><?php echo xlt('Document'); ?><% if (page.orderBy == 'DocType') { %> <i class='fa fa-arrow-<%= page.orderDesc ? ' up' : 'down' %>' /><% } %></th>
                    <th scope="col" id="header_CreateDate"><?php echo xlt('Create Date'); ?><% if (page.orderBy == 'CreateDate') { %> <i class='fa fa-arrow-<%= page.orderDesc ? ' up' : 'down' %>' /><% } %></th>
                    <th scope="col" id="header_ReviewDate"><?php echo xlt('Reviewed Date'); ?><% if (page.orderBy == 'ReviewDate') { %> <i class='fa fa-arrow-<%= page.orderDesc ? ' up' : 'down' %>' /><% } %></th>
                    <th scope="col" id="header_DenialReason"><?php echo xlt('Review Status'); ?><% if (page.orderBy == 'DenialReason') { %> <i class='fa fa-arrow-<%= page.orderDesc ? ' up' : 'down' %>' /><% } %></th>
                    <th scope="col" id="header_PatientSignedStatus"><?php echo xlt('Signed'); ?><% if (page.orderBy == 'PatientSignedStatus') { %> <i class='fa fa-arrow-<%= page.orderDesc ? ' up' : 'down' %>' /><% } %></th>
                    <th scope="col" id="header_PatientSignedTime"><?php echo xlt('Signed Date'); ?><% if (page.orderBy == 'PatientSignedTime') { %> <i class='fa fa-arrow-<%= page.orderDesc ? ' up' : 'down' %>' /><% } %></th>
                </tr>
                </thead>
                <tbody>
                <% items.each(function(item) {
                // if ((!isPortal && item.get('denialReason') == 'Locked')) return;
                %>
                <tr id="<%= _.escape(item.get('id')) %>">
                    <th scope="row"><%= _.escape(item.get('id') || '') %></th>
                    <td>
                        <button class='btn btn-outline-success history-btn'><%= _.escape(item.get('docType').slice(0, -4).replace(/_/g, ' ') || '') %></button>
                    </td>
                    <td><%if (item.get('createDate')) { %><%= item.get('createDate') %><% } else { %>NULL<% } %></td>
                    <td><%if (item.get('reviewDate') > '1969-12-31 24') { %><%= item.get('reviewDate') %><% } else { %>Pending<% } %></td>
                    <td><%= _.escape(item.get('denialReason') || 'Pending') %></td>
                    <td><%if (item.get('patientSignedStatus')=='1') { %><%= 'Yes' %><% } else { %>No<% } %></td>
                    <td><%if (item.get('patientSignedTime') > '1969-12-31 24') { %><%= item.get('patientSignedTime') %><% } else { %>Pending<% } %></td>
                </tr>
                <% }); %>
                </tbody>
            </table>
            <%= view.getPaginationHtml(page) %>
        </div>
        </div>
    </script>
<div class="container-lg px-3 pt-3 historyHide d-none" id="historyTable">
    <div id="onsiteDocumentCollectionContainer" class="collectionContainer"><!-- rendered history template --></div>
</div>
    </div>
<?php
// footer close body html
$this->display('_Footer.tpl.php');
?>
